==> lxqt-panel-1.4.0-1.src.tar.gz: lxqt-panel-1.4.0/plugin-sensors/translations/sensors_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>LXQtSensorsConfiguration</name>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="14"/>
        <source>Sensors Settings</source>
        <translation>Sensorinnstillinger</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="30"/>
        <source>Common</source>
        <translation>Felles</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="42"/>
        <source>Update interval (seconds)</source>
        <translation>Oppdateringsintervall (sekunder)</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="49"/>
        <source>Temperature bar width</source>
        <translation>Temperaturindikatorens bredde</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="104"/>
        <source>Temperature scale</source>
        <translation>Temperaturskala</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="110"/>
        <source>Celsius</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="120"/>
        <source>Fahrenheit</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="132"/>
        <source>Blink status bars when the temperature is too high</source>
        <translation>Blink med statuslinjen når temperaturen er for høy</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="138"/>
        <source>Warning about high temperature</source>
        <translation>Advarsel ved høy temperatur</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="152"/>
        <source>Sensors</source>
        <translation>Sensorer</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="168"/>
        <source>Detected chips:</source>
        <translation>Oppdagede kretser:</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="175"/>
        <source>Chip features:</source>
        <translation>Kretsers egenskaper:</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="203"/>
        <source>Enabled</source>
        <translation>På</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="203"/>
        <source>Label</source>
        <translation>Etikett</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="203"/>
        <source>Color</source>
        <translation>Farge</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.2.1-1.src.tar.gz: lxqt-panel-2.2.1/plugin-sensors/translations/sensors_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>LXQtSensorsConfiguration</name>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="14"/>
        <source>Sensors Settings</source>
        <translation>Sensorinnstillinger</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="30"/>
        <source>Common</source>
        <translation>Felles</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="42"/>
        <source>Update interval (seconds)</source>
        <translation>Oppdateringsintervall (sekunder)</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="74"/>
        <source>Temperature bar width</source>
        <translation>Temperaturindikatorens bredde</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="110"/>
        <source>Temperature scale</source>
        <translation>Temperaturskala</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="116"/>
        <source>Celsius</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="126"/>
        <source>Fahrenheit</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="91"/>
        <source>Blink status bars when the temperature is too high</source>
        <translation>Blinkende statuslinjer når temperaturen er for høy</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="97"/>
        <source>Warning about high temperature</source>
        <translation>Advarsel ved høy temperatur</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="152"/>
        <source>Sensors</source>
        <translation>Sensorer</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="158"/>
        <source>Detected chips:</source>
        <translation>Oppdagede kretser:</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="175"/>
        <source>Chip features:</source>
        <translation>Kretsers egenskaper:</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="203"/>
        <source>Enabled</source>
        <translation>På</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="203"/>
        <source>Label</source>
        <translation>Etikett</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="203"/>
        <source>Color</source>
        <translation>Farge</translation>
    </message>
</context>
</TS>
